// Copyright (c) 1998 Savvy Software
// Created by Matthijs Hollemans
// All Rights Reserved

#ifndef GOOWEE_FIT_H
#define GOOWEE_FIT_H

// ***************************************************************************
// System Includes
// ***************************************************************************

#include <Font.h>
#include <Rect.h>
#include <Point.h>

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"          // Standard type and constant definitions

// ***************************************************************************
// External Name Declarations
// ***************************************************************************

// ***************************************************************************
// External Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

/** Name of the default font. */
#define GOOWEE_FIT_DEFAULT_FONT be_plain_font

/** Size of the default font. */
const float GOOWEE_FIT_DEFAULT_FONT_SIZE = 12.0;

// ***************************************************************************
// Type Definitions
// ***************************************************************************

// ***************************************************************************
// Class Definition
// ***************************************************************************

// ***************************************************************************
// Global Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Inline Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

/**
 * Adjust a BRect to the size of a BFont.
 *
 * @Param aRect  The rectangle that will be adjusted.
 * @Param apFont A pointer to the default font. This parameter is not
 *               required. Its default is GOOWEE_FIT_DEFAULT_FONT.
 *
 * @Returns The adjusted rectangle.
 */
BRect Goowee_Fit(BRect aRect, 
                 const BFont* apFont = GOOWEE_FIT_DEFAULT_FONT);

/** 
 * Adjust a BPoint to the size of a BFont.
 *
 * @Param aPoint The point that will be adjusted.
 * @Param apFont A pointer to the default font. This parameter is not
 *               required. Its default is GOOWEE_FIT_DEFAULT_FONT.
 *
 * @Returns The adjusted point.
 */ 
BPoint Goowee_Fit(BPoint aPoint, 
                  const BFont* apFont = GOOWEE_FIT_DEFAULT_FONT);

/** 
 * Adjust a floating point value to the size of a BFont
 *
 * @Param aFloat The floating point value that will be adjusted.
 * @Param apFont A pointer to the default font. This parameter is not
 *               required. Its default is GOOWEE_FIT_DEFAULT_FONT.
 *
 * @Returns The adjusted floating point value.
 */
tFloat Goowee_Fit(tFloat aFloat, 
                  const BFont* apFont = GOOWEE_FIT_DEFAULT_FONT);

#endif // GOOWEE_FIT_H
