// Copyright (c) 1998 Savvy Software
// Created by Matthijs Hollemans
// All Rights Reserved

// StyleGuideDefs.h for BeOS

#ifndef BEOS_STYLEGUIDEDEFS_H
#define BEOS_STYLEGUIDEDEFS_H

/**
 * [COMPILER] Include file differences between Metrowerks CodeWarrior and gcc.
 *
 * Unlike CodeWarrior, gcc doesn't seem to support pre-compiled header files.
 * Therefore, we need to include all relevant header files ourselves. Because
 * I'm lazy, I've simply added #include <Be.h> at the top of StyleGuideDefs.h.
 * Probably not the fastest way to do things, but definitly the easiest ;-)
 *
 * There is a slight annoyance, however. The original Tracker Grep sources used
 * a file called "Window.h", which defines my tWindow class based on BWindow.
 * But BWindow's header file is also called "Window.h". This was no problem with
 * CodeWarrior; it knew which file belonged to my project and which file was a
 * BeOS system include. Unfortunately, gcc doesn't and complained that BWindow
 * had "an invalid type". After a long search, I figured it had to be a header
 * file name clash and renamed my file to "GrepWindow.h". Guess what? No problems
 * whatsoever. So, I guess it's wise not to use header file names in the future 
 * that are called like the BeOS system header file names. 
 */

#include <Be.h>

// Common BeOS type definitions
#include <SupportDefs.h>

#undef NULL
#undef FALSE
#undef TRUE

const int NULL  = 0;
const int FALSE = 0;
const int TRUE  = 1;

typedef void          tVoid;

typedef bool          tBool;

typedef char          tChar;
typedef unsigned char tUChar;

typedef int8          tInt8;
typedef uint8         tUInt8;

typedef int16         tInt16;
typedef uint16        tUInt16;

typedef int32         tInt32;
typedef uint32        tUInt32;

typedef int64         tInt64;
typedef uint64        tUInt64;

typedef float         tFloat;
typedef double        tDouble;
typedef long double   tLongDouble;

#endif // BEOS_STYLEGUIDEDEFS_H
